==> kdegraphics-3.0.1-i386-1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkmultipage.so )
( cd opt/kde/lib ; ln -sf libkmultipage.so.0.0.0 libkmultipage.so )
( cd opt/kde/lib ; rm -rf libkmultipage.so.0 )
( cd opt/kde/lib ; ln -sf libkmultipage.so.0.0.0 libkmultipage.so.0 )
( cd opt/kde/lib ; rm -rf libkscan.so )
( cd opt/kde/lib ; ln -sf libkscan.so.1.0.0 libkscan.so )
( cd opt/kde/lib ; rm -rf libkscan.so.1 )
( cd opt/kde/lib ; ln -sf libkscan.so.1.0.0 libkscan.so.1 )
( cd opt/kde/share/doc/HTML/en/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdvi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kfract ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kfract ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kghostview ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kiconedit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kooka ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpaint ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kruler ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kuickshow ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kview ; ln -sf /opt/kde/share/doc/HTML/en/common common )

==> kdegraphics-3.1.3-i386-1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkscan.so )
( cd opt/kde/lib ; ln -sf libkscan.so.1.0.0 libkscan.so )
( cd opt/kde/lib ; rm -rf libkviewsupport.so.0 )
( cd opt/kde/lib ; ln -sf libkviewsupport.so.0.0.0 libkviewsupport.so.0 )
( cd opt/kde/lib ; rm -rf libkmultipage.so.0 )
( cd opt/kde/lib ; ln -sf libkmultipage.so.0.0.0 libkmultipage.so.0 )
( cd opt/kde/lib ; rm -rf libkviewsupport.so )
( cd opt/kde/lib ; ln -sf libkviewsupport.so.0.0.0 libkviewsupport.so )
( cd opt/kde/lib ; rm -rf libkscan.so.1 )
( cd opt/kde/lib ; ln -sf libkscan.so.1.0.0 libkscan.so.1 )
( cd opt/kde/lib ; rm -rf libkmultipage.so )
( cd opt/kde/lib ; ln -sf libkmultipage.so.0.0.0 libkmultipage.so )
( cd opt/kde/share/doc/HTML/en/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdvi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kooka ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kview ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kamera ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpaint ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kruler ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kuickshow ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kiconedit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kghostview ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/en/common common )
